==> lxqt-config-0.15.0.tar.xz: lxqt-config-0.15.0/lxqt-config-locale/translations/lxqt-config-locale_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="47"/>
        <source>Re&amp;gion:</source>
        <translation>Om&amp;råde:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="76"/>
        <source>De&amp;tailed Settings</source>
        <translation>De&amp;taljerte innstillinger</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="83"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Tall:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="112"/>
        <source>&amp;Time:</source>
        <translation>&amp;Tid:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="141"/>
        <source>Currenc&amp;y:</source>
        <translation>&amp;Valuta:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="170"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Måleenheter:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="199"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>So&amp;rteringsrekkefølge:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
        <translation>&lt;b&gt;Eksempler&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="248"/>
        <source>Numbers:</source>
        <translation>Tall:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="268"/>
        <source>Time:</source>
        <translation>Tid:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="288"/>
        <source>Currency:</source>
        <translation>Valuta:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="308"/>
        <source>Measurement Units:</source>
        <translation>Måleenheter:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="125"/>
        <source>No change</source>
        <translation>Ingen forandring</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="314"/>
        <source>Format Settings Changed</source>
        <translation>Formateringsinnstillinger ble forandret</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="315"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Ønsker du å lagre endringene? De vil begynne å virke neste gang du logger inn.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="436"/>
        <source>Imperial UK</source>
        <translation>Britiske måleenheter</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="440"/>
        <source>Imperial US</source>
        <translation>Amerikanske måleenheter</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="444"/>
        <source>Metric</source>
        <translation>Metrisk</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>LXQt Locale Configuration</source>
        <translation>LXQt språk- og stedsinnstilling</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Locale Settings</source>
        <translation>Språk- og stedsinnstilllinger</translation>
    </message>
</context>
</TS>

==> lxqt-config-2.2.0.tar.xz: lxqt-config-2.2.0/lxqt-config-locale/translations/lxqt-config-locale_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="31"/>
        <source>Re&amp;gion:</source>
        <translation>&amp;Region:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="60"/>
        <source>De&amp;tailed Settings</source>
        <translation>De&amp;taljerte innstillinger</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="78"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Tall:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="107"/>
        <source>&amp;Time:</source>
        <translation>&amp;Tid:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="136"/>
        <source>Currenc&amp;y:</source>
        <translation>&amp;Valuta:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="165"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Måleenheter:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="194"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>&amp;Sammenstilling og sortering:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="226"/>
        <source>Examples</source>
        <translation>Eksempler</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>Numbers:</source>
        <translation>Tall:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="258"/>
        <source>Time:</source>
        <translation>Tid:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="289"/>
        <source>Currency:</source>
        <translation>Valuta:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="309"/>
        <source>Measurement Units:</source>
        <translation>Måleenheter:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="164"/>
        <source>Unset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="226"/>
        <source>Current: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="370"/>
        <source>Format Settings Changed</source>
        <translation>Formateringsinnstillinger ble forandret</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="371"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Ønsker du å lagre endringene? De vil begynne å virke neste gang du logger inn.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="518"/>
        <source>Imperial UK</source>
        <translation>Britiske måleenheter</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="522"/>
        <source>Imperial US</source>
        <translation>Amerikanske måleenheter</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="526"/>
        <source>Metric</source>
        <translation>Metrisk</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>LXQt Locale Configuration</source>
        <translation>LXQt språk- og stedsinnstilling</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Locale Settings</source>
        <translation>Språk- og stedsinnstilllinger</translation>
    </message>
</context>
</TS>
